"""DNScheck constants."""

from enum import StrEnum, unique


@unique
class NssetCheckStatus(StrEnum):
    """Nsset check status.

    Attributes:
        STARTED: Nsset check has been started. Domain checks were created.
        EVALUATED: Nsset check results have been evaluated.
        FINISHED: Nsset check is finished. If the check failed, notifications
            have been sent.
    """

    STARTED = "started"
    EVALUATED = "evaluated"
    FINISHED = "finished"


@unique
class DomainCheckStatus(StrEnum):
    """Domain check status."""

    CREATED = "created"
    STARTED = "started"
    FINISHED = "finished"


@unique
class NssetCheckResult(StrEnum):
    """Nsset check result."""

    FAIL = "fail"
    SUCCESS = "success"


@unique
class NssetCheckProfile(StrEnum):
    """Nsset check profile."""

    DEFAULT = "default"


@unique
class TestResultLevel(StrEnum):
    """Test result level.

    https://doc.zonemaster.fr/latest/specifications/tests/SeverityLevelDefinitions.html
    """

    INFO = "INFO"
    NOTICE = "NOTICE"
    WARNING = "WARNING"
    ERROR = "ERROR"
    CRITICAL = "CRITICAL"
