import re
from functools import partial
from typing import Any
from uuid import UUID

from setapp.utils import override_settings as _override_settings

from dnscheck.constants import DomainCheckStatus
from dnscheck.db import DomainCheck, Nsset, NssetCheck
from dnscheck.settings import APP

override_settings = partial(_override_settings, APP)


class ModelFactory:
    def __init__(self):
        self._last: dict[type, Any] = {
            Nsset: None,
            NssetCheck: None,
            DomainCheck: None,
        }

    def nsset(self, id: int, **kwargs):
        defaults = {
            "nsset_id": UUID(int=id).hex,
            "handle": f"HANDLE-{id}",
        }
        defaults.update(kwargs)
        self._last[Nsset] = Nsset(**defaults)
        return self._last[Nsset]

    def nsset_check(self, id: int, **kwargs):
        defaults = {
            "nsset_id": UUID(int=id).hex,
            "nsset_history_id": UUID(int=1024 + id).hex,
            "handle": f"HANDLE-{id}",
            "nameservers": [],
        }
        defaults.update(kwargs)
        self._last[NssetCheck] = NssetCheck(**defaults)
        return self._last[NssetCheck]

    def domain_check(self, fqdn: str, **kwargs):
        defaults = {
            "nsset_check": self._last[NssetCheck],
            "domain": fqdn,
            "test_id": None if kwargs.get("status") == DomainCheckStatus.CREATED else f"test:{fqdn}",
        }
        defaults.update(kwargs)
        self._last[DomainCheck] = DomainCheck(**defaults)
        return self._last[DomainCheck]


def slugify(value: str) -> str:
    return re.sub(r"[^A-Za-z0-9_]", "_", value)
